hash stringlengths 40 40 | diff stringlengths 131 114k | message stringlengths 7 980 | project stringlengths 5 67 | split stringclasses 1
value |
|---|---|---|---|---|
6101a30e4147c4058521d947a56edc0c8dd6b9c4 | diff --git a/src/autocommand/autoparse.py b/src/autocommand/autoparse.py
index <HASH>..<HASH> 100644
--- a/src/autocommand/autoparse.py
+++ b/src/autocommand/autoparse.py
@@ -87,7 +87,7 @@ def _make_arguments(param, used_char_args, add_nos):
# If there is no explicit type, and the default is present and not None... | Minor updates and comments to autoparse | Lucretiel_autocommand | train |
db6fbc9a91e963ac98b398d15fa99f1f09754309 | diff --git a/pybar/fei4_run_base.py b/pybar/fei4_run_base.py
index <HASH>..<HASH> 100644
--- a/pybar/fei4_run_base.py
+++ b/pybar/fei4_run_base.py
@@ -7,7 +7,7 @@ import struct
import smtplib
from socket import gethostname
from functools import wraps
-from threading import Event, Thread, current_thread, Lock, RLock
... | REG: fix Ctrl-c behavior | SiLab-Bonn_pyBAR | train |
ec3b7c3a5d46e43c769c97123fa9ce07651c3112 | diff --git a/src/core/style/expressions/ramp.js b/src/core/style/expressions/ramp.js
index <HASH>..<HASH> 100644
--- a/src/core/style/expressions/ramp.js
+++ b/src/core/style/expressions/ramp.js
@@ -110,8 +110,8 @@ export default class Ramp extends Expression {
for (var i = 0; i < width; i++) {
... | Make rgba types consistent with CSS ranges | CartoDB_carto-vl | train |
6c03acb968c1e2ebf078e90ffddb2425a12896f1 | diff --git a/CHANGELOG.md b/CHANGELOG.md
index <HASH>..<HASH> 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,4 +1,8 @@
# winrm-s Change Log
+Release: 0.3.5
+--------------
+* Fixes incompatibility with winrm 1.6 where a consuming gem sets the transport option to `:negotiate` and results in an error since this gem... | Fixes incompatibility with winrm <I> | chef-boneyard_winrm-s | train |
4e455bc7227d94362a359d6a4d57a46935ed61d4 | diff --git a/features/serializer/deserialize_objects_using_constructor.feature b/features/serializer/deserialize_objects_using_constructor.feature
index <HASH>..<HASH> 100644
--- a/features/serializer/deserialize_objects_using_constructor.feature
+++ b/features/serializer/deserialize_objects_using_constructor.feature
@... | Fixed denormalization of a constructor argument which is a collection of non-resources | api-platform_core | train |
745538f6d421ee31cc05392e1845bbf6b6f3d4a4 | diff --git a/source/application/routes/pattern.js b/source/application/routes/pattern.js
index <HASH>..<HASH> 100644
--- a/source/application/routes/pattern.js
+++ b/source/application/routes/pattern.js
@@ -62,7 +62,7 @@ export default function patternRouteFactory (application, configuration) {
// Reset the script... | fix(routes/pattern): harden against missing script-dependencies | patternplate-archive_patternplate-server | train |
8537aaa188f4600008d31ed2c39b43ee6a55945a | diff --git a/lib/Thelia/Core/Template/Loop/CategoryTree.php b/lib/Thelia/Core/Template/Loop/CategoryTree.php
index <HASH>..<HASH> 100644
--- a/lib/Thelia/Core/Template/Loop/CategoryTree.php
+++ b/lib/Thelia/Core/Template/Loop/CategoryTree.php
@@ -47,6 +47,7 @@ class CategoryTree extends BaseI18nLoop implements ArraySea... | Loop CategoryTree optimisation
For a big catalogue (4 <I> categories), without it takes about <I> <I>ms
to have the "product-edit" or "category-edit" pages.
With this optimisation we fall about <I> <I>ms
Conflicts:
core/lib/Thelia/Core/Template/Loop/CategoryTree.php | thelia_core | train |
edd79767b798cc4175c1a81844bbb7554dd2588b | diff --git a/cloudstack-cli.gemspec b/cloudstack-cli.gemspec
index <HASH>..<HASH> 100644
--- a/cloudstack-cli.gemspec
+++ b/cloudstack-cli.gemspec
@@ -11,7 +11,7 @@ Gem::Specification.new do |gem|
gem.description = %q{cloudstack-cli is a CloudStack API command line client written in Ruby.}
gem.summary = %... | promote cs environment add instead of cs setup | niwo_cloudstack-cli | train |
b074b5a91d6551c1956f198b0726dae5ae5b8c84 | diff --git a/js/ast.go b/js/ast.go
index <HASH>..<HASH> 100644
--- a/gym/lib/gym/runner.rb
+++ b/gym/lib/gym/runner.rb
@@ -127,6 +127,7 @@ module Gym
# Compress and move the dsym file
containing_directory = File.expand_path("..", PackageCommandGenerator.dsym_path)
+ bcsymbol... | Include contents of BCSymbolMaps directory in dSYM.zip file. (#<I>)
* Include contents of BCSymbolMaps directory in dSYM.zip file.
* Do not mess with the directory structure of the generated .dSYM.zip. | fastlane_fastlane | train |
c27dd2350469360a8794004c95e1681fecab06e3 | diff --git a/src/arrays.php b/src/arrays.php
index <HASH>..<HASH> 100644
--- a/src/arrays.php
+++ b/src/arrays.php
@@ -248,16 +248,18 @@ function array_getColumn (array $array, $key)
*/
function array_insertAfter (array $array, $after, $value, $key = null)
{
- if (is_null ($after)) {
+ if (is_null ($after) || !is... | FIX: array_insertAfter() not working properly. | php-kit_tools | train |
fc7e9033b36b39eabd47b9ccd7669ea0f2b20353 | diff --git a/lib/scoped_search/rails_helper.rb b/lib/scoped_search/rails_helper.rb
index <HASH>..<HASH> 100644
--- a/lib/scoped_search/rails_helper.rb
+++ b/lib/scoped_search/rails_helper.rb
@@ -94,7 +94,7 @@ module ScopedSearch
function << "'#{field_id}', "
function << "'" + (options[:update] || "#{field... | helper support for JQury as well as prototype | wvanbergen_scoped_search | train |
c6a8de28881d968aab4fb843fbfeadcfde98fe0d | diff --git a/examples/umd.html b/examples/umd.html
index <HASH>..<HASH> 100644
--- a/examples/umd.html
+++ b/examples/umd.html
@@ -7,7 +7,8 @@
<script src="https://unpkg.com/react@16/umd/react.development.js"></script>
<script src="https://unpkg.com/react-dom@16/umd/react-dom.development.js"></script>
<script ... | fix addons, include Animation in addon bundle | react-spring_react-spring | train |
e817865d9806b0b3f624a1490d3bc32dc7fee945 | diff --git a/src/prebid.js b/src/prebid.js
index <HASH>..<HASH> 100644
--- a/src/prebid.js
+++ b/src/prebid.js
@@ -276,18 +276,15 @@ $$PREBID_GLOBAL$$.setTargetingForAst = function(adUnitCodes) {
events.emit(SET_TARGETING, targeting.getAllTargeting());
};
-function emitAdRenderFail(reason, message, bid) {
- cons... | added adId property to adRenderFailed event (#<I>)
When no bid (therefore no adUnitCode) is available in the adRenderFailed event it can be difficult to identify the erroring slot.But in almost all cases the given slot still has the adId targeting. | prebid_Prebid.js | train |
3556206dcca2047b455f95e0583175ecaed0663f | diff --git a/extensions/profiledevkit b/extensions/profiledevkit
index <HASH>..<HASH> 160000
--- a/extensions/profiledevkit
+++ b/extensions/profiledevkit
@@ -1 +1 @@
-Subproject commit 32256045bdb01b5cb873a817acce6bd06ed724b5
+Subproject commit b611ea1bb221a04c05a4ab3ff75ea4e71e87019a
diff --git a/symphony/assets/symp... | Possible fix for issue #<I>. | symphonycms_symphony-2 | train |
59056c1e67d9547f07d8497cbd7b62439c43307f | diff --git a/core/src/playn/core/gl/GLShader.java b/core/src/playn/core/gl/GLShader.java
index <HASH>..<HASH> 100644
--- a/core/src/playn/core/gl/GLShader.java
+++ b/core/src/playn/core/gl/GLShader.java
@@ -106,7 +106,6 @@ public abstract class GLShader {
public GLShader prepareTexture(int tex, float alpha) {
/... | Nixed debug logging. | threerings_playn | train |
13a27deea13a15be8b94e889018f678bcd867ba7 | diff --git a/builder/amazonebs/artifact.go b/builder/amazonebs/artifact.go
index <HASH>..<HASH> 100644
--- a/builder/amazonebs/artifact.go
+++ b/builder/amazonebs/artifact.go
@@ -1,14 +1,19 @@
package amazonebs
import (
- "errors"
"fmt"
+ "github.com/mitchellh/goamz/ec2"
+ "github.com/mitchellh/packer/packer"
+ "... | builder/amazonebs: Implement Artifact.Destroy | hashicorp_packer | train |
a67ae30db42b74ebd1e8b050892f54c090acc877 | diff --git a/test/schema/v1.0.0/converter-v1-to-v2.test.js b/test/schema/v1.0.0/converter-v1-to-v2.test.js
index <HASH>..<HASH> 100644
--- a/test/schema/v1.0.0/converter-v1-to-v2.test.js
+++ b/test/schema/v1.0.0/converter-v1-to-v2.test.js
@@ -272,5 +272,37 @@ describe('v1.0.0 ==> v2.0.0', function () {
r... | Added test to ensure v1->v2 conversion does not error out when invalid response ids are provided in responses_order | postmanlabs_postman-collection-transformer | train |
d0bc43fe933a5c9dd74e8cb11d183e832a24a992 | diff --git a/Rakefile b/Rakefile
index <HASH>..<HASH> 100644
--- a/Rakefile
+++ b/Rakefile
@@ -1,6 +1,11 @@
require "bundler/gem_tasks"
+require "rspec/core/rake_task"
desc "Open an irb session preloaded with this library"
task :console do
sh "irb -rubygems -I lib -r codeship.rb"
end
+
+RSpec::Core::RakeTask.n... | Update codeship base URL (#<I>)
* Update codeship base url
* Set rspec as the default rake task
* Fix broken rspec tests | codeship_codeship-ruby | train |
7f6caf152ec5aa6711432eeaf2ac10a8fc54ca88 | diff --git a/lib/util.js b/lib/util.js
index <HASH>..<HASH> 100644
--- a/lib/util.js
+++ b/lib/util.js
@@ -246,15 +246,8 @@ exports.isFile = function(path) {
return false;
};
-exports.isFileP = function(path) {
- return Q.when(QW.execute(FS.stat, path),
- function(stat) {
- return stat.isFi... | Fix `util.isFileP()` and mark it as deprecated | bem-archive_bem-tools | train |
f3d669bfb108e94b07ddac8809007a2f284400f1 | diff --git a/lib/excon/socket.rb b/lib/excon/socket.rb
index <HASH>..<HASH> 100644
--- a/lib/excon/socket.rb
+++ b/lib/excon/socket.rb
@@ -39,7 +39,7 @@ module Excon
def read(max_length)
begin
until @read_buffer.length >= max_length
- @read_buffer << @socket.read_nonblock(max_length)
+ ... | don't read more than max_length, as it messes with chunked | excon_excon | train |
7a8c29ddabb31c16e908552fb0dd8558a4700b41 | diff --git a/tests/test_fields.py b/tests/test_fields.py
index <HASH>..<HASH> 100644
--- a/tests/test_fields.py
+++ b/tests/test_fields.py
@@ -8,7 +8,7 @@ class User(object):
self.last_name = last_name
def full_name(self):
- return '{} {}'.format(self.first_name, self.last_name)
+ return '... | Make test compatible with Python <I> | bulv1ne_moarjson | train |
ed93a88e0810a384298871614bdd48eeda4facac | diff --git a/src/bind-action-creators.js b/src/bind-action-creators.js
index <HASH>..<HASH> 100644
--- a/src/bind-action-creators.js
+++ b/src/bind-action-creators.js
@@ -6,7 +6,7 @@ function bindActionCreator (actionCreator, dispatch) {
};
}
-export function bindActionCreators (actionCreators, dispatch) {
+module... | knew I should have asked for a review, missed one export | StreamMeDev_flux-store | train |
47d89b18aef0125179386274c4445b90f66fa3c9 | diff --git a/lib/arel/visitors/to_sql.rb b/lib/arel/visitors/to_sql.rb
index <HASH>..<HASH> 100644
--- a/lib/arel/visitors/to_sql.rb
+++ b/lib/arel/visitors/to_sql.rb
@@ -199,7 +199,7 @@ module Arel
collector << quote(value, attr && column_for(attr)).to_s
end
unless i == len
- ... | Update to_sql.rb. Slightly performance improment.
Update to_sql.rb. Slightly performance improment. | rails_rails | train |
a3940ef9db3ea91dcc0b30f8b097caa937900c8d | diff --git a/core/server/web/site/app.js b/core/server/web/site/app.js
index <HASH>..<HASH> 100644
--- a/core/server/web/site/app.js
+++ b/core/server/web/site/app.js
@@ -11,7 +11,7 @@ const apps = require('../../services/apps');
const constants = require('../../lib/constants');
const storage = require('../../adapter... | Simplified urlUtils require path
no-issue
This was previously going to a parent directory which was shared by both modules | TryGhost_Ghost | train |
aa153a8b0f42d247aed2a263af5b1e590eb37659 | diff --git a/src/gitgraph.js b/src/gitgraph.js
index <HASH>..<HASH> 100644
--- a/src/gitgraph.js
+++ b/src/gitgraph.js
@@ -1108,21 +1108,24 @@
var alpha = rotate( this.parentCommit.y - this.y, this.parentCommit.x - this.x );
// Merge & Fork case
- if ( this.type === "mergeCommit" || this === this.branch.... | Fix arrow on commits that are pushed by another | nicoespeon_gitgraph.js | train |
bf8d93653b339b482a26f49935f12ff239c5b267 | diff --git a/hammer.js b/hammer.js
index <HASH>..<HASH> 100644
--- a/hammer.js
+++ b/hammer.js
@@ -172,8 +172,8 @@ function Hammer(element, options, undefined)
body = doc.body;
return [{
- x: event.pageX || event.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft... | Fix for event normalization
Just a minor typo fix: it was checking for body then applying properties
from doc, should have ben checking for body then applying properties
from body. This affects I believe IEs, maybe only old ones. | hammerjs_hammer.js | train |
171a1b2209ccb68e8123453c77f659561913b9f5 | diff --git a/CHANGELOG.md b/CHANGELOG.md
index <HASH>..<HASH> 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,3 +1,6 @@
+# 0.9.2 / 2014-04-30
+* [BIGFIX] Do not add suffix to queue names - added by Propono.
+
# 0.9.1 / 2014-04-30
* [FEATURE] Raise exceptions when thread dies
diff --git a/lib/larva/listener.rb b... | Remove duplicate suffix from queue name. | iHiD_larva | train |
b95d7501dff6df10eeecf2710dd73952c96b6c1a | diff --git a/iterm2_tools/images.py b/iterm2_tools/images.py
index <HASH>..<HASH> 100644
--- a/iterm2_tools/images.py
+++ b/iterm2_tools/images.py
@@ -7,7 +7,7 @@ import base64
# See https://iterm2.com/images.html
IMAGE_CODE = '\033]1337;File={file};inline={inline};size={size}:{base64_img}\a'
-def image_bytes(b, fi... | Rename image_bytes to display_image_bytes | asmeurer_iterm2-tools | train |
ae93eacc9b9325d5882d9c664e636688c86953f8 | diff --git a/woothee.go b/woothee.go
index <HASH>..<HASH> 100644
--- a/woothee.go
+++ b/woothee.go
@@ -29,7 +29,15 @@ const (
)
var (
- EmptyResult = &Result{ValueUnknown, ValueUnknown, ValueUnknown, ValueUnknown, ValueUnknown, ValueUnknown, ValueUnknown}
+ EmptyResult = &Result{
+ Name: ValueUnknown,
+ Ca... | Use named fields [ci skip] | woothee_woothee-go | train |
623ff8108efb54788a0af7714988b5e1d9bec1d4 | diff --git a/trunk/JLanguageTool/src/java/de/danielnaber/languagetool/tokenizers/br/BretonWordTokenizer.java b/trunk/JLanguageTool/src/java/de/danielnaber/languagetool/tokenizers/br/BretonWordTokenizer.java
index <HASH>..<HASH> 100644
--- a/trunk/JLanguageTool/src/java/de/danielnaber/languagetool/tokenizers/br/BretonWo... | [br] fixed a bug in the Breton word tokenizer that could cause
wrong positioning in highlighting of errors and could
even cause an exception. | languagetool-org_languagetool | train |
dadbe733768c49a137313a727f4ca97365e777e3 | diff --git a/pyqode/python/__init__.py b/pyqode/python/__init__.py
index <HASH>..<HASH> 100644
--- a/pyqode/python/__init__.py
+++ b/pyqode/python/__init__.py
@@ -141,6 +141,3 @@ class QPythonCodeEdit(pyqode.core.QCodeEdit):
__all__ = ["PEP8CheckerMode", 'PyHighlighterMode', 'PyAutoIndentMode',
"__versio... | pyQode does not use data files anymore | pyQode_pyqode.python | train |
d8fd6258573111a881cc0a7320d61bc91235291d | diff --git a/lib/rory/controller.rb b/lib/rory/controller.rb
index <HASH>..<HASH> 100644
--- a/lib/rory/controller.rb
+++ b/lib/rory/controller.rb
@@ -107,7 +107,11 @@ module Rory
end
def generate_json_from_object(object, opts = {})
- object.to_json
+ if object.respond_to?(:to_hash)
+ objec... | Better rendering of objects responding to #to_hash | screamingmuse_rory | train |
56234e8740fc62bb68593f1db849a0d61f6b369a | diff --git a/src/sap.m/src/sap/m/ResponsivePopoverRenderer.js b/src/sap.m/src/sap/m/ResponsivePopoverRenderer.js
index <HASH>..<HASH> 100644
--- a/src/sap.m/src/sap/m/ResponsivePopoverRenderer.js
+++ b/src/sap.m/src/sap/m/ResponsivePopoverRenderer.js
@@ -11,6 +11,7 @@ sap.ui.define([],
* @namespace
*/
var Respo... | [INTERNAL] sap.m.ResponsivePopover: Migrating to new semantic rendering
-- The control is now using the new semantic rendering syntax
and setting the apiVersion:2 flag so that in-place DOM patching
can be used.
Change-Id: Id2ba<I>c<I>b<I>d9ead<I>c<I>a4ed<I>c<I> | SAP_openui5 | train |
f2872daa85d3b4d9a2ec040084855819c9bcbc80 | diff --git a/nameko/messaging.py b/nameko/messaging.py
index <HASH>..<HASH> 100644
--- a/nameko/messaging.py
+++ b/nameko/messaging.py
@@ -160,11 +160,12 @@ class ConsumeProvider(DecoratorDependency):
def call_result(self, worker_ctx, result=None, exc=None):
message = self.pending_worker_message.pop(wor... | handle_message_processed interface reflects it's true dependency on srv_ctx | nameko_nameko | train |
9615f9b552409b6b49125ec1342f5370c96d0187 | diff --git a/src/frontend/org/voltdb/iv2/TransactionTask.java b/src/frontend/org/voltdb/iv2/TransactionTask.java
index <HASH>..<HASH> 100644
--- a/src/frontend/org/voltdb/iv2/TransactionTask.java
+++ b/src/frontend/org/voltdb/iv2/TransactionTask.java
@@ -103,10 +103,7 @@ public abstract class TransactionTask extends Si... | ENG-<I>-PreserveSpOptimization | VoltDB_voltdb | train |
612dcc0267548c85172270681c152ea4f3a6f253 | diff --git a/server/sandbox_run.go b/server/sandbox_run.go
index <HASH>..<HASH> 100644
--- a/server/sandbox_run.go
+++ b/server/sandbox_run.go
@@ -5,6 +5,7 @@ import (
"fmt"
"net"
"os"
+ "path"
"path/filepath"
"regexp"
"strconv"
@@ -15,7 +16,6 @@ import (
"github.com/kubernetes-incubator/cri-o/libkpod/san... | Add k8s function to compress cgroupfs path to systemd
We are copying this to avoid getting in lots of dependencies.
We also remove now unused function. | cri-o_cri-o | train |
09aa538bc39c382928fce988f7719f87da7a558a | diff --git a/Eloquent/Collection.php b/Eloquent/Collection.php
index <HASH>..<HASH> 100755
--- a/Eloquent/Collection.php
+++ b/Eloquent/Collection.php
@@ -67,19 +67,16 @@ class Collection extends BaseCollection {
*/
public function contains($key, $value = null)
{
- if (func_num_args() == 1 && ! $key instanceof ... | Simplify eloquent collection contains | illuminate_database | train |
2e6322212109c6b0d68e4402876c1b2fcc00f474 | diff --git a/lib/jara/releaser.rb b/lib/jara/releaser.rb
index <HASH>..<HASH> 100644
--- a/lib/jara/releaser.rb
+++ b/lib/jara/releaser.rb
@@ -16,6 +16,7 @@ module Jara
def initialize(environment, bucket_name, options={})
@environment = environment
@bucket_name = bucket_name
+ @re_release = opti... | Make it possible to force artifact uploads
And avoid listing the S3 bucket (so that a releaser don’t need that permission). | burtcorp_jara | train |
bf5d20836c21518d1975e9c90607fbaf382f0f9f | diff --git a/htmresearch/frameworks/layers/simple_object_machine.py b/htmresearch/frameworks/layers/simple_object_machine.py
index <HASH>..<HASH> 100644
--- a/htmresearch/frameworks/layers/simple_object_machine.py
+++ b/htmresearch/frameworks/layers/simple_object_machine.py
@@ -165,7 +165,9 @@ class SimpleObjectMachine... | add option to get unions of locations | numenta_htmresearch | train |
e027003616fcd13c84d3f1db2ddd3054088b59df | diff --git a/DependencyInjection/Compiler/NewRelicCompilerPass.php b/DependencyInjection/Compiler/NewRelicCompilerPass.php
index <HASH>..<HASH> 100644
--- a/DependencyInjection/Compiler/NewRelicCompilerPass.php
+++ b/DependencyInjection/Compiler/NewRelicCompilerPass.php
@@ -32,5 +32,6 @@ class NewRelicCompilerPass impl... | Fixed removing exception listener if New Relic module isn't installed | ekino_EkinoNewRelicBundle | train |
556d99be2613e41daec2492d275f0ce0bb737ad3 | diff --git a/packages/node_modules/@webex/internal-plugin-ediscovery/src/ediscovery.js b/packages/node_modules/@webex/internal-plugin-ediscovery/src/ediscovery.js
index <HASH>..<HASH> 100644
--- a/packages/node_modules/@webex/internal-plugin-ediscovery/src/ediscovery.js
+++ b/packages/node_modules/@webex/internal-plugi... | feat(ediscovery): applying limits for file size and total included files | webex_spark-js-sdk | train |
bd4ad516e0bfb91a4cd18f2f20b60dfb450bdba4 | diff --git a/tests/test_treewalkers.py b/tests/test_treewalkers.py
index <HASH>..<HASH> 100644
--- a/tests/test_treewalkers.py
+++ b/tests/test_treewalkers.py
@@ -2,10 +2,13 @@ import os
import sys
import StringIO
import unittest
+import warnings
+
+warnings.simplefilter("error")
from support import html5lib_test... | Make treewalker tests deal gracefully with warnings and add public/sys id support to pulldom
--HG--
extra : convert_revision : svn%3Aacbfec<I>-<I>-<I>-a<I>-<I>a<I>e<I>e0/trunk%<I> | html5lib_html5lib-python | train |
871d72e04e8db950bc204493aa00358a9939726c | diff --git a/tasks/cordovacli.js b/tasks/cordovacli.js
index <HASH>..<HASH> 100644
--- a/tasks/cordovacli.js
+++ b/tasks/cordovacli.js
@@ -48,7 +48,8 @@ module.exports = function (grunt) {
runCordova = function (args, opts, done) {
var cordova_cli, spawn_cmd;
- cordova_cli = path.join(cordova_pat... | Pipe output of spawned cordova
In order to get output of cordova process visible piping output to cordovacli process. | csantanapr_grunt-cordovacli | train |
4e6a6dc8df8859b0092f692f962114a4bc89f3a6 | diff --git a/src/Brokerage/OrderIntent.php b/src/Brokerage/OrderIntent.php
index <HASH>..<HASH> 100644
--- a/src/Brokerage/OrderIntent.php
+++ b/src/Brokerage/OrderIntent.php
@@ -13,6 +13,7 @@ class OrderIntent extends \CFX\JsonApi\AbstractResource implements OrderIntentIn
'priceLow' => null,
'referr... | Added referenceNum to OrderIntent (refs #<I>) | cfxmarkets_php-public-models | train |
c443374e8b30dd6ae027b52c76b20b3a8125ae71 | diff --git a/asyncpg/connection.py b/asyncpg/connection.py
index <HASH>..<HASH> 100644
--- a/asyncpg/connection.py
+++ b/asyncpg/connection.py
@@ -321,23 +321,17 @@ class Connection(metaclass=ConnectionMeta):
:param float timeout: Optional timeout value in seconds.
:return None: This method discards t... | Adjust executemany() docs
Remove the `copy_records_to_table()` note as `executemany()` is almost
as efficient now and rephrase the note about the new behavior with
respect to atomicity. | MagicStack_asyncpg | train |
d907cc4031a4e13279f2b7ab2c7b0fb7957535bb | diff --git a/nose/test_quantity.py b/nose/test_quantity.py
index <HASH>..<HASH> 100644
--- a/nose/test_quantity.py
+++ b/nose/test_quantity.py
@@ -2818,6 +2818,61 @@ def test_actionAngle_inconsistentPotentialUnits_error():
lambda x: actionAngleIsochroneApprox(b=0.8,pot=pot,ro=8.,vo=220.),())
ret... | Test that error is raised when orbit given to actionAngle method does not have the same unit system as the class itself | jobovy_galpy | train |
fae55a67a0f03c0f3ad0ca0d9e4007b9872be9b4 | diff --git a/core/src/main/java/io/grpc/CallOptions.java b/core/src/main/java/io/grpc/CallOptions.java
index <HASH>..<HASH> 100644
--- a/core/src/main/java/io/grpc/CallOptions.java
+++ b/core/src/main/java/io/grpc/CallOptions.java
@@ -68,8 +68,6 @@ public final class CallOptions {
@Nullable
private CallCredential... | core: delete deprecated affinity API. (#<I>)
Deprecated since <I>
Resolves #<I> | grpc_grpc-java | train |
82722d80c62b346d901f07253f28cfa9d9cdc3cd | diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -48,7 +48,7 @@ def read_file(filename, alt=None):
lines = None
try:
- with open(filename) as f:
+ with open(filename, encoding='utf-8') as f:
lines = f.read()
except IOError:
... | setup.py: Match file.open encoding with the source code encoding.
Hit encoding errors on Windows after <I>, easiest solution is to match encodings. | coursera-dl_coursera-dl | train |
4967744e69dd8b1d58154be6d77d7a95d6774ef1 | diff --git a/transformer.js b/transformer.js
index <HASH>..<HASH> 100644
--- a/transformer.js
+++ b/transformer.js
@@ -1,5 +1,8 @@
'use strict';
+var querystring = require('querystring').parse
+ , url = require('url').parse;
+
/**
* Transformer skeletons
*
@@ -45,6 +48,8 @@ Transformer.prototype.initialise = f... | [minor] Actually accept test against requests | primus_primus | train |
be96db1d1dadcb8f30152565da1f804833b68c77 | diff --git a/config/webpack/webpack.config.ssr.js b/config/webpack/webpack.config.ssr.js
index <HASH>..<HASH> 100644
--- a/config/webpack/webpack.config.ssr.js
+++ b/config/webpack/webpack.config.ssr.js
@@ -19,6 +19,7 @@ const {
webpackDecorator,
polyfills,
isStartScript,
+ sourceMapsProd,
supportedBrowser... | feat: Add support for sourceMapsProd in SSR (#<I>) | seek-oss_sku | train |
fe4bc4ab38bad444fc825fa3016680b0f871cd81 | diff --git a/src/Sulu/Bundle/ContactBundle/Resources/public/js/components/contact-form/main.js b/src/Sulu/Bundle/ContactBundle/Resources/public/js/components/contact-form/main.js
index <HASH>..<HASH> 100644
--- a/src/Sulu/Bundle/ContactBundle/Resources/public/js/components/contact-form/main.js
+++ b/src/Sulu/Bundle/Con... | now showing overlay on selecting new address field | sulu_sulu | train |
973db14523d338fa4e772574fe4d49763fb25245 | diff --git a/torchvision/models/_utils.py b/torchvision/models/_utils.py
index <HASH>..<HASH> 100644
--- a/torchvision/models/_utils.py
+++ b/torchvision/models/_utils.py
@@ -41,7 +41,7 @@ class IntermediateLayerGetter(nn.ModuleDict):
"return_layers": Dict[str, str],
}
- def __init__(self, model: nn.... | Fixed typing in constructors of models submodules (#<I>)
* fix: Fixed constructor typing in models._utils
* fix: Fixed constructor typing in models.alexnet
* fix: Fixed constructor typing in models.mnasnet
* fix: Fixed constructor typing in models.squeezenet | pytorch_vision | train |
19cdeee0d187c676f85aa8c487561d266e9704fa | diff --git a/pycanvas/assignment.py b/pycanvas/assignment.py
index <HASH>..<HASH> 100644
--- a/pycanvas/assignment.py
+++ b/pycanvas/assignment.py
@@ -22,7 +22,6 @@ class Assignment(CanvasObject):
response = self._requester.request(
'DELETE',
'courses/%s/assignments/%s' % (self.course... | removed even='delete' | ucfopen_canvasapi | train |
e881a24d311b16de4daace1761fb47a97c1473bf | diff --git a/lib/core/config/collection.rb b/lib/core/config/collection.rb
index <HASH>..<HASH> 100644
--- a/lib/core/config/collection.rb
+++ b/lib/core/config/collection.rb
@@ -6,50 +6,63 @@ class Collection
#-----------------------------------------------------------------------------
# Property accessor / mod... | Ensuring the configuration collection is parallel capable and changing the save file name. | coralnexus_nucleon | train |
638787d5b10624f5b8bd25aef9285b3dc51777da | diff --git a/manager/impl/src/main/java/org/jboss/forge/furnace/manager/impl/AddonManagerImpl.java b/manager/impl/src/main/java/org/jboss/forge/furnace/manager/impl/AddonManagerImpl.java
index <HASH>..<HASH> 100644
--- a/manager/impl/src/main/java/org/jboss/forge/furnace/manager/impl/AddonManagerImpl.java
+++ b/manager... | FURNACE-<I>: Core addons should never be updated | forge_furnace | train |
d098c22494f1a2c2d25c6f65ef2617dcfddedffc | diff --git a/packages/node_modules/pouchdb-fetch/src/fetch.js b/packages/node_modules/pouchdb-fetch/src/fetch.js
index <HASH>..<HASH> 100644
--- a/packages/node_modules/pouchdb-fetch/src/fetch.js
+++ b/packages/node_modules/pouchdb-fetch/src/fetch.js
@@ -1,6 +1,6 @@
'use strict';
-import nodeFetch from 'node-fetch';... | (#<I>) - node-fetch Headers not from default export | pouchdb_pouchdb | train |
8ec1fa10911e8037482598f8fdb5f68283074d33 | diff --git a/structr-ui/src/main/java/org/structr/web/importer/Importer.java b/structr-ui/src/main/java/org/structr/web/importer/Importer.java
index <HASH>..<HASH> 100644
--- a/structr-ui/src/main/java/org/structr/web/importer/Importer.java
+++ b/structr-ui/src/main/java/org/structr/web/importer/Importer.java
@@ -220,7... | Bugfix: Added negative lookahead to regex so that colgroup is not changed | structr_structr | train |
08bee06945f6832fe47f969578e5c1ad16b42865 | diff --git a/mesh_tensorflow/transformer/utils.py b/mesh_tensorflow/transformer/utils.py
index <HASH>..<HASH> 100644
--- a/mesh_tensorflow/transformer/utils.py
+++ b/mesh_tensorflow/transformer/utils.py
@@ -196,6 +196,36 @@ def _logical_to_physical(physical_shape, mesh_shape):
@gin.configurable
+def learning_rate_... | add linear learning-rate decay for the last <I>% of training.
PiperOrigin-RevId: <I> | tensorflow_mesh | train |
7f28eb7a677a76756f90ac6579627514216eb214 | diff --git a/skitai/wastuff/futures.py b/skitai/wastuff/futures.py
index <HASH>..<HASH> 100644
--- a/skitai/wastuff/futures.py
+++ b/skitai/wastuff/futures.py
@@ -60,7 +60,8 @@ class Tasks (TaskBase):
class CompletedTasks (Tasks):
- def __init__ (self, rss):
+ def __init__ (self, rss, timeout = 10, c... | fix CompletedTasks | hansroh_skitai | train |
772dc82286665255ad6c2eabfa7ad67178282346 | diff --git a/src/main/java/redis/clients/jedis/BinaryClient.java b/src/main/java/redis/clients/jedis/BinaryClient.java
index <HASH>..<HASH> 100644
--- a/src/main/java/redis/clients/jedis/BinaryClient.java
+++ b/src/main/java/redis/clients/jedis/BinaryClient.java
@@ -855,7 +855,11 @@ public class BinaryClient extends Co... | Add CONFIG REWRITE support (#<I>) | xetorthio_jedis | train |
42d347ce369099e63038fe175ffdf0f8b03d1d83 | diff --git a/master/buildbot/test/unit/test_changes_p4poller.py b/master/buildbot/test/unit/test_changes_p4poller.py
index <HASH>..<HASH> 100644
--- a/master/buildbot/test/unit/test_changes_p4poller.py
+++ b/master/buildbot/test/unit/test_changes_p4poller.py
@@ -376,6 +376,37 @@ class TestP4Poller(changesource.ChangeSo... | Add negative unit test to p4poller ticket parsing
FIXME: P4Poller should probably fail on ticket parsing failure. | buildbot_buildbot | train |
e02f13ff33f2820a7374f03585ac33d5dead696e | diff --git a/Resources/public/js/views/ez-navigationhubview.js b/Resources/public/js/views/ez-navigationhubview.js
index <HASH>..<HASH> 100644
--- a/Resources/public/js/views/ez-navigationhubview.js
+++ b/Resources/public/js/views/ez-navigationhubview.js
@@ -619,11 +619,13 @@ YUI.add('ez-navigationhubview', function (Y... | EZP-<I>: Make sure static string in navigation hub are correctly translated | ezsystems_PlatformUIBundle | train |
7fdcbd0b433f9c30459f17527a05e5a87eb8efab | diff --git a/pylib/cqlshlib/helptopics.py b/pylib/cqlshlib/helptopics.py
index <HASH>..<HASH> 100644
--- a/pylib/cqlshlib/helptopics.py
+++ b/pylib/cqlshlib/helptopics.py
@@ -226,7 +226,7 @@ class CQLHelpTopics(object):
CollatingOrderPreservingPartitioner both require UTF-8 keys.
In cql3 mode, a tab... | add help topic COMPOUND_PRIMARY_KEYS for cqlsh
patch by dbrosius reviewed by jbellis for cassandra-<I> | Stratio_stratio-cassandra | train |
7c06368a7da9e445ad03b75650cf4bfc25ff738d | diff --git a/src/Output/OutputInterface.php b/src/Output/OutputInterface.php
index <HASH>..<HASH> 100644
--- a/src/Output/OutputInterface.php
+++ b/src/Output/OutputInterface.php
@@ -34,6 +34,13 @@ interface OutputInterface
public function newLine(): OutputInterface;
/**
+ * Clear output and home cursor... | Added method clear to OutputInterface. | extendsframework_extends-console | train |
2e50275f0fa7f5e6723357ef9d4b22748266f21f | diff --git a/lib/stl-parser.js b/lib/stl-parser.js
index <HASH>..<HASH> 100644
--- a/lib/stl-parser.js
+++ b/lib/stl-parser.js
@@ -1,4 +1,4 @@
-require=(function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);throw new Error("Cannot fin... | - updated dependencies handling for three.js
* also regenerated built lib | usco_usco-stl-parser | train |
5fc2c43b8c80b97830ac7d6d51f3df5bf02e0b6c | diff --git a/src/js/bokeh.js b/src/js/bokeh.js
index <HASH>..<HASH> 100644
--- a/src/js/bokeh.js
+++ b/src/js/bokeh.js
@@ -49,6 +49,10 @@
ref : function(){
return {'type' : this.type,
'id' : this.id};
+ },
+ resolve_ref : function(ref){
+ var self = this;
+ return Bokeh.Collections[ref['type']].g... | added resolve_ref function to HasReference, so they know how to get objects out of references | bokeh_bokeh | train |
978216d35064df443a8a0083059f125b1785492f | diff --git a/wrapper/xgboost.py b/wrapper/xgboost.py
index <HASH>..<HASH> 100644
--- a/wrapper/xgboost.py
+++ b/wrapper/xgboost.py
@@ -920,7 +920,7 @@ class XGBModel(XGBModelBase):
self.base_score = base_score
self.seed = seed
- self.missing = missing or np.nan
+ self.missing = missing... | ENH: Allow missing = 0 | dmlc_xgboost | train |
8c2ec991db743a77fa3b3f60a148e858b58a4fd6 | diff --git a/src/Bundle/JoseFramework/Helper/ConfigurationHelper.php b/src/Bundle/JoseFramework/Helper/ConfigurationHelper.php
index <HASH>..<HASH> 100644
--- a/src/Bundle/JoseFramework/Helper/ConfigurationHelper.php
+++ b/src/Bundle/JoseFramework/Helper/ConfigurationHelper.php
@@ -207,7 +207,7 @@ final class Configura... | Apply fixes from StyleCI (#<I>)
[ci skip] [skip ci] | web-token_jwt-framework | train |
10d9fc857e72fdb5490b1d27b1df0f73f0a4084f | diff --git a/drools-core/src/main/java/org/drools/common/DefaultAgenda.java b/drools-core/src/main/java/org/drools/common/DefaultAgenda.java
index <HASH>..<HASH> 100644
--- a/drools-core/src/main/java/org/drools/common/DefaultAgenda.java
+++ b/drools-core/src/main/java/org/drools/common/DefaultAgenda.java
@@ -261,10 +2... | JBRULES-<I>: fixing deserialization of timers | kiegroup_drools | train |
1d391bf58375c41f53adcfcf787ea9a6dabc52cc | diff --git a/aiohttp/client.py b/aiohttp/client.py
index <HASH>..<HASH> 100644
--- a/aiohttp/client.py
+++ b/aiohttp/client.py
@@ -153,7 +153,7 @@ def request(method, url, *,
url = urllib.parse.urldefrag(r_url)[0]
if url:
- resp.close()
+ yield from asyncio.Task... | fix #<I>: read body until eof | aio-libs_aiohttp | train |
5d8151548711aabe2bb2f8159b8a4c98a49aaa9a | diff --git a/aiogram/bot/base.py b/aiogram/bot/base.py
index <HASH>..<HASH> 100644
--- a/aiogram/bot/base.py
+++ b/aiogram/bot/base.py
@@ -727,7 +727,8 @@ class BaseBot:
return await self.request(api.Methods.GET_FILE, payload)
- async def kick_chat_member(self, chat_id: Union[Integer, String], user_id: ... | Fixed lost "Optional" flags. | aiogram_aiogram | train |
2b423e105dc61f0bb2fa4bc50259e9485e32bfbc | diff --git a/modules/missenaBidAdapter.js b/modules/missenaBidAdapter.js
index <HASH>..<HASH> 100644
--- a/modules/missenaBidAdapter.js
+++ b/modules/missenaBidAdapter.js
@@ -72,11 +72,29 @@ export const spec = {
return bidResponses;
},
- getUserSyncs: function (syncOptions, serverResponses) {
+ getUserSync... | Missena bidAdapter: pass gdpr data to sync frame (#<I>) | prebid_Prebid.js | train |
2da5fd57fe7220aa0fa880a067006fea4f31a1ae | diff --git a/astrobase/lcproc.py b/astrobase/lcproc.py
index <HASH>..<HASH> 100644
--- a/astrobase/lcproc.py
+++ b/astrobase/lcproc.py
@@ -1236,6 +1236,7 @@ def variability_threshold(featuresdir,
magcols=None,
errcols=None,
lcformat='hat-s... | lcproc.variability_threshold: get and plot LC RMS as well | waqasbhatti_astrobase | train |
dddaeb4bc8048dbb4a661f52b942057f3d389aeb | diff --git a/crispy/gui/widgets/plotwidget.py b/crispy/gui/widgets/plotwidget.py
index <HASH>..<HASH> 100644
--- a/crispy/gui/widgets/plotwidget.py
+++ b/crispy/gui/widgets/plotwidget.py
@@ -27,12 +27,13 @@ from __future__ import absolute_import, division, unicode_literals
__authors__ = ['Marius Retegan']
__license... | Reduce the size of the icons on macOS | mretegan_crispy | train |
1b9a49768260ddcf6ecc6ab05a97ae42214e7916 | diff --git a/lib/cli/index.js b/lib/cli/index.js
index <HASH>..<HASH> 100644
--- a/lib/cli/index.js
+++ b/lib/cli/index.js
@@ -181,7 +181,6 @@ cli.exec = function exec (command, argv, done) {
else if (!cmd) {
if (!method) { throw new Error('Unknown method'); }
- var server = require(path.join(__dirname, '.... | explicitly instantiate redis client instead of requiring the server | anvilresearch_connect | train |
a1e925bb4aae31534f51984d886fc628915ed5a5 | diff --git a/beets/mediafile.py b/beets/mediafile.py
index <HASH>..<HASH> 100644
--- a/beets/mediafile.py
+++ b/beets/mediafile.py
@@ -342,8 +342,9 @@ class StorageStyle(object):
describe more sophisticated translations or format-specific access
strategies.
- MediaFile uses a StorageStyle via two methods... | Delete tags from media files
Original: beetbox/beets@<I>d<I>c | beetbox_mediafile | train |
ccb2394782f18d94fe687fcfa3015f0089252510 | diff --git a/fat/directory_cluster.go b/fat/directory_cluster.go
index <HASH>..<HASH> 100644
--- a/fat/directory_cluster.go
+++ b/fat/directory_cluster.go
@@ -9,6 +9,7 @@ import (
"math"
"time"
"unicode/utf16"
+ "strings"
)
type DirectoryAttr uint8
@@ -341,8 +342,8 @@ func DecodeDirectoryClusterEntry(data []b... | fat: ensure that DecodeDirectoryClusterEntry(...) removes the trailing whitespace from it's <I> name.
This prevents DirectoryEntry.ShortName() and DirectoryClusterEntry.Bytes() from considering the . and .. directories as <I> filenames to split instead of the special cased entries that they are. | mitchellh_go-fs | train |
86537a4a7b21562104d24a5f39d9c4806f1a1eb1 | diff --git a/scopus/scopus_reports.py b/scopus/scopus_reports.py
index <HASH>..<HASH> 100644
--- a/scopus/scopus_reports.py
+++ b/scopus/scopus_reports.py
@@ -6,8 +6,15 @@ from .scopus_author import ScopusAuthor
def report(scopus_search, label):
- """Print out an org-mode report for the results from the scopus_... | Fix bug with multiple ISSNs given; Add link to author page | scopus-api_scopus | train |
7f33405dd70fb836d025c54d186fb465774aa16c | diff --git a/src/Mpociot/BotMan/BotMan.php b/src/Mpociot/BotMan/BotMan.php
index <HASH>..<HASH> 100644
--- a/src/Mpociot/BotMan/BotMan.php
+++ b/src/Mpociot/BotMan/BotMan.php
@@ -215,7 +215,7 @@ class BotMan
$answerText = $this->getConversationAnswer()->getValue();
$text = '/^'.preg_replace('/\{(\w+... | Apply fixes from StyleCI (#<I>) | botman_botman | train |
7a13d217d3bb621082de9fdb06ee3f21ce3b1485 | diff --git a/lib/jirahelper/issue.rb b/lib/jirahelper/issue.rb
index <HASH>..<HASH> 100644
--- a/lib/jirahelper/issue.rb
+++ b/lib/jirahelper/issue.rb
@@ -15,9 +15,6 @@ module JiraHelper
# @return [Type Array] 0-m JIRA Issues returned from query
def fetch_issues(jql)
client.Issue.jql(jql)
- rescue
-... | [misc] Update myissues to be more descriptive with JIRA problems
Fixes up code coverage stat, and refactors the myissues command a bit so
that users aren't misled by a JIRA problem. | esigler_lita-jira | train |
c0eb0107b9abca5832147895e2529f53100b5159 | diff --git a/chef/spec/unit/provider/deploy_spec.rb b/chef/spec/unit/provider/deploy_spec.rb
index <HASH>..<HASH> 100644
--- a/chef/spec/unit/provider/deploy_spec.rb
+++ b/chef/spec/unit/provider/deploy_spec.rb
@@ -47,6 +47,7 @@ describe Chef::Provider::Deploy do
before do
FileUtils.should_receive(:mkdir_p)... | CHEF-<I>: Update tests for moved File.exists?
Since we now check File.exist? in the recipe_eval block, we need to stub out
Dir.chdir | chef_chef | train |
a6bf29b9c2a4927ffd9efd7464007915cb18c9e0 | diff --git a/hammer.js b/hammer.js
index <HASH>..<HASH> 100644
--- a/hammer.js
+++ b/hammer.js
@@ -469,16 +469,16 @@ function Hammer(element, options, undefined)
}
// for non-touch
else {
- // Listen for mouseup on the document so we know it happens
- // even if the mouse has left the eleme... | added check for addEventListener to prevent older IE error, added check for child.parentNode, fixed typo | hammerjs_hammer.js | train |
ce0d81af2780766ad82233b1376340ef92a90342 | diff --git a/src/Parse.php b/src/Parse.php
index <HASH>..<HASH> 100644
--- a/src/Parse.php
+++ b/src/Parse.php
@@ -332,7 +332,7 @@ class Parse
$emailAddress['invalid_reason'] = 'Email address contains whitespace';
} else {
// If the prev... | Scrutinizer Auto-Fixes
This commit consists of patches automatically generated for this project on <URL> | mmucklo_email-parse | train |
d3b20757efc779b42a1a43daef8e8e0e2e636ef4 | diff --git a/dependency-check-core/src/test/java/org/owasp/dependencycheck/data/update/BaseUpdaterTest.java b/dependency-check-core/src/test/java/org/owasp/dependencycheck/data/update/BaseUpdaterTest.java
index <HASH>..<HASH> 100644
--- a/dependency-check-core/src/test/java/org/owasp/dependencycheck/data/update/BaseUpd... | changed to BaseDBTest instead of BaseTest to reesolve build errors per issue #<I>
Former-commit-id: <I>b<I>cac<I>d6dd6c9a4ffbd2d<I>f<I>c8c7ed | jeremylong_DependencyCheck | train |
0f45d9862e72b80c37e78da415216e46c986ee47 | diff --git a/src/Web/Controller/BaseController.php b/src/Web/Controller/BaseController.php
index <HASH>..<HASH> 100644
--- a/src/Web/Controller/BaseController.php
+++ b/src/Web/Controller/BaseController.php
@@ -55,13 +55,6 @@ class BaseController implements ControllerProviderInterface {
}
/**
- * @return Session... | Move getSession to test merging with master | gmo_common | train |
bbc608c108a305d18e711897c6dadb0556afe9b8 | diff --git a/core/src/main/java/pl/allegro/tech/embeddedelasticsearch/ElasticServer.java b/core/src/main/java/pl/allegro/tech/embeddedelasticsearch/ElasticServer.java
index <HASH>..<HASH> 100644
--- a/core/src/main/java/pl/allegro/tech/embeddedelasticsearch/ElasticServer.java
+++ b/core/src/main/java/pl/allegro/tech/em... | Do not throw exception when reading from stdout of ES during shutdown (#<I>) (#<I>) | allegro_embedded-elasticsearch | train |
72dcce2ffe2bc2c0981c7b45d867be803048e50c | diff --git a/src/Nayjest/Grids/FieldConfig.php b/src/Nayjest/Grids/FieldConfig.php
index <HASH>..<HASH> 100644
--- a/src/Nayjest/Grids/FieldConfig.php
+++ b/src/Nayjest/Grids/FieldConfig.php
@@ -78,6 +78,10 @@ class FieldConfig
return $this->is_sortable;
}
+ /**
+ * @param boolean $is_sortable
+ ... | grid.prepare event added, GridConfig::addColumn, Filtering::getFilter(name) made public | Nayjest_Grids | train |
229cc7b43f88ed6f1b4947328121038ed4e42ad5 | diff --git a/lib/rack/tracker/criteo/criteo.rb b/lib/rack/tracker/criteo/criteo.rb
index <HASH>..<HASH> 100644
--- a/lib/rack/tracker/criteo/criteo.rb
+++ b/lib/rack/tracker/criteo/criteo.rb
@@ -30,7 +30,7 @@ class Criteo < Rack::Tracker::Handler
Tilt.new( File.join( File.dirname(__FILE__), 'template', 'criteo.er... | make track API for criteo a bit more human-friendly and added more specs | railslove_rack-tracker | train |
01edd7229814f5967d5ff0da90ce1b95f678630d | diff --git a/axes/test_settings.py b/axes/test_settings.py
index <HASH>..<HASH> 100644
--- a/axes/test_settings.py
+++ b/axes/test_settings.py
@@ -35,18 +35,6 @@ INSTALLED_APPS = [
SECRET_KEY = 'too-secret-for-test'
-LOGGING = {
- 'version': 1,
- 'root': {
- 'level': 'DEBUG',
- 'handlers': ['co... | Improved tests so it really looks for the rabbit in the hole | jazzband_django-axes | train |
6257679c430d58597034ea7669b261eda29f65f0 | diff --git a/psiturk/amt_services.py b/psiturk/amt_services.py
index <HASH>..<HASH> 100644
--- a/psiturk/amt_services.py
+++ b/psiturk/amt_services.py
@@ -322,6 +322,7 @@ class MTurkServices:
self.mtc.grant_bonus(workerId, assignment_id, bonus, reason)
return True
except MTurkRequestE... | Print errors in bonus_worker
Useful while getting the kinks out. | NYUCCL_psiTurk | train |
e1b9efc5bc5c3636799291b762c6723ea8c4eff2 | diff --git a/ELiDE/ELiDE/board/board.py b/ELiDE/ELiDE/board/board.py
index <HASH>..<HASH> 100644
--- a/ELiDE/ELiDE/board/board.py
+++ b/ELiDE/ELiDE/board/board.py
@@ -230,10 +230,9 @@ class Board(RelativeLayout):
def on_touch_up(self, touch):
if hasattr(self, 'protodest'):
- self.portal_touch... | Make Board.on_touch_up return True when successfully made portal | LogicalDash_LiSE | train |
fd53d5894fc0831f714f82350611afa807e10aa5 | diff --git a/pylast.py b/pylast.py
index <HASH>..<HASH> 100644
--- a/pylast.py
+++ b/pylast.py
@@ -21,7 +21,7 @@
# http://code.google.com/p/pylast/
__name__ = 'pylast'
-__version__ = '0.3.1'
+__version__ = '0.3.2'
__doc__ = 'A Python interface to Last.fm'
__author__ = 'Amr Hassan'
__email__ = 'amr.hassan@gmail.c... | * removed all encoding from string and unicode objects. | pylast_pylast | train |
07922810862bc5f1aec325f393a935c819ec28f9 | diff --git a/lib/google_apps/atom/atom.rb b/lib/google_apps/atom/atom.rb
index <HASH>..<HASH> 100644
--- a/lib/google_apps/atom/atom.rb
+++ b/lib/google_apps/atom/atom.rb
@@ -29,20 +29,21 @@ module GoogleApps
ENTRY_TAG = ["<atom:entry xmlns:atom=\"#{NAMESPACES[:atom]}\" xmlns:apps=\"#{NAMESPACES[:apps]}\" xmlns:... | Module level helpers in GoogleApps::Atom working again. | LeakyBucket_google_apps | train |
b5a8e6184408b50dda0ba6477de61e53e63b1957 | diff --git a/src/pfs/pfstest/pfs_test.go b/src/pfs/pfstest/pfs_test.go
index <HASH>..<HASH> 100644
--- a/src/pfs/pfstest/pfs_test.go
+++ b/src/pfs/pfstest/pfs_test.go
@@ -6,7 +6,9 @@ import (
"io"
"io/ioutil"
"os"
+ "runtime"
"strings"
+ "sync"
"sync/atomic"
"testing"
@@ -40,10 +42,13 @@ var (
)
func ... | add a little bit of parallelism to pfs test | pachyderm_pachyderm | train |
ac6bce044822c73108eeb398df5542ccc9284074 | diff --git a/lib/weixin_authorize/version.rb b/lib/weixin_authorize/version.rb
index <HASH>..<HASH> 100644
--- a/lib/weixin_authorize/version.rb
+++ b/lib/weixin_authorize/version.rb
@@ -1,3 +1,3 @@
module WeixinAuthorize
- VERSION = "1.0.0"
+ VERSION = "1.0.1"
end | updated version <I>, fixed some bugs and refactor | lanrion_weixin_authorize | train |
23ff70d682b205ead41eb6aef104ec7558851216 | diff --git a/util/btcctl/btcctl.go b/util/btcctl/btcctl.go
index <HASH>..<HASH> 100644
--- a/util/btcctl/btcctl.go
+++ b/util/btcctl/btcctl.go
@@ -55,6 +55,7 @@ var commandHandlers = map[string]*handlerData{
"getconnectioncount": &handlerData{0, 0, displayFloat64, nil, makeGetConnectionCount, ""},
"getdifficulty"... | Add gethashespersec command to btcctl. | btcsuite_btcd | train |
e0226c90393bc2ed7d020da0cae2c7eb5e3a2df8 | diff --git a/helper/schema/schema.go b/helper/schema/schema.go
index <HASH>..<HASH> 100644
--- a/helper/schema/schema.go
+++ b/helper/schema/schema.go
@@ -638,7 +638,9 @@ func (m schemaMap) diff(
}
for attrK, attrV := range unsupressedDiff.Attributes {
- if schema.DiffSuppressFunc != nil && schema.DiffSuppressFu... | core: Check for attrV being nil before dereference
This can be an issue with unset computed fields.
Fixes #<I>. | hashicorp_terraform | train |
e547578b4debd334d5e9336bb54ab09538699b40 | diff --git a/tests/ProxyManagerTest/ProxyGenerator/NullObject/MethodGenerator/StaticProxyConstructorTest.php b/tests/ProxyManagerTest/ProxyGenerator/NullObject/MethodGenerator/StaticProxyConstructorTest.php
index <HASH>..<HASH> 100644
--- a/tests/ProxyManagerTest/ProxyGenerator/NullObject/MethodGenerator/StaticProxyCon... | Tested `StaticProxyConstructor` visibility flags, as discovered by mutation testing suite | Ocramius_ProxyManager | train |
c7a571a35df8076f62c7f21dd3400be980181c6e | diff --git a/robber/matchers/base.py b/robber/matchers/base.py
index <HASH>..<HASH> 100644
--- a/robber/matchers/base.py
+++ b/robber/matchers/base.py
@@ -1,7 +1,6 @@
from termcolor import colored
from robber.bad_expectation import BadExpectation
-from robber.expect import expect
class Base:
@@ -26,7 +25,7 @@ ... | [f] Better success message
Now print "True" in ipython and python shell if an expectation passes. | vesln_robber.py | train |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.
--- a/js/ast.go
+++ b/js/ast.go
@@ -7,8 +7,8 @@ import (
)
type AST struct {
- Comment []byte // first comment in file
- BlockStmt // module
+ Comments [][]byte // first comments in file
+ BlockStmt // module
}
func (ast *AST) Str... | JS: store all comments that appear first in file | tdewolff_parse | train |
1d4ed866b7f7c1c4e9a32a04b8a528eef22b1cdd | diff --git a/gym/lib/gym/runner.rb b/gym/lib/gym/runner.rb
index <HASH>..<HASH> 100644